Linux workstation

Fedora 43 native package

libffado-devel

Free firewire audio driver library development headers

Packages / Fedora 43 / Unspecified / libffado-devel

[Source: libffado]

Package: libffado-devel (2.4.9-8.fc43)

[Project overview: libffado]

External Resources:

Homepage: [www.ffado.org]

Similar packages:

  • [ffado]

    Free firewire audio driver library applications and utilities

  • [libffado]

    Free firewire audio driver library

Free firewire audio driver library development headers

Development files needed to build applications against libffado.

Other Packages Related to libffado-devel:

  • dep: /usr/bin/pkg-config

    Package not available

  • dep: libffado(aarch-64) (= 2.4.9-8.fc43)

    Package not available

  • dep: libffado.so.2()(64bit)

    Package not available

Download libffado-devel

ArchitecturePackage SizeInstalled SizeFiles
aarch64134 KiB563 KiB[list of files]
i686134 KiB563 KiB[list of files]
x86_64134 KiB563 KiB[list of files]

Percorsi file del pacchetto (41)

Paths come from the repository package-file index for the observed builds. They describe archive/package associations, not every file that will exist on a running system after maintainer scripts, alternatives, generated state, diversions, or installation choices.

  • /usr/include/libffado
  • /usr/include/libffado/ffado.h
  • /usr/lib64/libffado.so
  • /usr/lib64/pkgconfig/libffado.pc
  • /usr/lib/libffado.so
  • /usr/lib/pkgconfig/libffado.pc
  • /usr/share/doc/libffado-devel
  • /usr/share/doc/libffado-devel/html
  • /usr/share/doc/libffado-devel/html/annotated.html
  • /usr/share/doc/libffado-devel/html/classes.html
  • /usr/share/doc/libffado-devel/html/clipboard.js
  • /usr/share/doc/libffado-devel/html/dir_6e8c217afbb1bb0ba4979df1f37ad8c3.html
  • /usr/share/doc/libffado-devel/html/doxygen_crawl.html
  • /usr/share/doc/libffado-devel/html/doxygen.css
  • /usr/share/doc/libffado-devel/html/doxygen.svg
  • /usr/share/doc/libffado-devel/html/dynsections.js
  • /usr/share/doc/libffado-devel/html/ffado_8h.html
  • /usr/share/doc/libffado-devel/html/ffado_8h_source.html
  • /usr/share/doc/libffado-devel/html/files.html
  • /usr/share/doc/libffado-devel/html/functions.html
  • /usr/share/doc/libffado-devel/html/functions_vars.html
  • /usr/share/doc/libffado-devel/html/globals_defs.html
  • /usr/share/doc/libffado-devel/html/globals_enum.html
  • /usr/share/doc/libffado-devel/html/globals_eval.html
  • /usr/share/doc/libffado-devel/html/globals_func.html
  • /usr/share/doc/libffado-devel/html/globals.html
  • /usr/share/doc/libffado-devel/html/globals_type.html
  • /usr/share/doc/libffado-devel/html/graph_legend.html
  • /usr/share/doc/libffado-devel/html/graph_legend.md5
  • /usr/share/doc/libffado-devel/html/graph_legend.png
  • /usr/share/doc/libffado-devel/html/index.html
  • /usr/share/doc/libffado-devel/html/index.qhp
  • /usr/share/doc/libffado-devel/html/jquery.js
  • /usr/share/doc/libffado-devel/html/menudata.js
  • /usr/share/doc/libffado-devel/html/menu.js
  • /usr/share/doc/libffado-devel/html/navtree.css
  • /usr/share/doc/libffado-devel/html/structffado__device__info.html
  • /usr/share/doc/libffado-devel/html/structffado__device__info-members.html
  • /usr/share/doc/libffado-devel/html/structffado__options.html
  • /usr/share/doc/libffado-devel/html/structffado__options-members.html
  • /usr/share/doc/libffado-devel/html/tabs.css

Field source: Fedora 43 Everything aarch64 revision 43-everything-aarch64:6431612747d987257399969298151d19cfe87ed26322be6987e7b00cd0ae66a2

Usa questo pacchetto

OpenFactory può avviare questo sistema operativo in una macchina virtuale del browser, o iniziare una costruzione che include il nome nativo del pacchetto di questo record.

Versioni, suite e repository

Ogni riga è metadato dell'indice pacchetti per una versione, architettura, suite e repository. Nomi, URL e dimensioni arrivano dalla fonte; un link è un punto di recupero mutabile, non una redistribuzione OpenFactory.

VersionReleaseArchitectureRepositoryPackage sizeInstalled sizePublisher repository artifact
2.4.9-8.fc4343 / everythingaarch64Fedora 43 · Everything · aarch64134 KiB563 KiBPackages/l/libffado-devel-2.4.9-8.fc43.aarch64.rpm
2.4.9-8.fc4343 / everythingi686Fedora 43 · Everything · x86_64134 KiB563 KiBPackages/l/libffado-devel-2.4.9-8.fc43.i686.rpm
2.4.9-8.fc4343 / everythingx86_64Fedora 43 · Everything · x86_64134 KiB563 KiBPackages/l/libffado-devel-2.4.9-8.fc43.x86_64.rpm

Field source: Fedora 43 Everything aarch64 revision 43-everything-aarch64:6431612747d987257399969298151d19cfe87ed26322be6987e7b00cd0ae66a2

Checksum e date di osservazione

For an APT source, signature verification authenticates the repository metadata chain and the Packages index containing this source-reported artifact digest. It does not certify package safety.

2.4.9-8.fc43 / aarch64Observed Sep 1, 2026 to Sep 1, 2026

Verification status: Metadata observed; artifact bytes were not independently fetched or hashed by this catalog import. The digest below is source-reported.

Source-reported sha256: e7f16bf5d60bb16eb117e30d7858822f5fbb42fadc7cf7883d8b56044774b2d4

After downloading that exact artifact, compare its bytes with the source-reported expected digest:

printf '%s %s\n' 'e7f16bf5d60bb16eb117e30d7858822f5fbb42fadc7cf7883d8b56044774b2d4' 'libffado-devel-2.4.9-8.fc43.aarch64.rpm' | sha256sum --check --strict -

A match establishes equality with the repository metadata value. It does not establish safety or catalog-side artifact retrieval.

Field source: Fedora 43 Everything aarch64 revision 43-everything-aarch64:6431612747d987257399969298151d19cfe87ed26322be6987e7b00cd0ae66a2

2.4.9-8.fc43 / i686Observed Sep 1, 2026 to Sep 1, 2026

Verification status: Metadata observed; artifact bytes were not independently fetched or hashed by this catalog import. The digest below is source-reported.

Source-reported sha256: 83939691a8e6552c25acdba7f2f58937a8b68d3007add6bf254cb5fe704532cf

After downloading that exact artifact, compare its bytes with the source-reported expected digest:

printf '%s %s\n' '83939691a8e6552c25acdba7f2f58937a8b68d3007add6bf254cb5fe704532cf' 'libffado-devel-2.4.9-8.fc43.i686.rpm' | sha256sum --check --strict -

A match establishes equality with the repository metadata value. It does not establish safety or catalog-side artifact retrieval.

Field source: Fedora 43 Everything x86_64 revision 43-everything-x86_64:eb1d8634a798b5cfcef64b0114711f431f2cd186b55cce902f1883a32c6ff4f2

2.4.9-8.fc43 / x86_64Observed Sep 1, 2026 to Sep 1, 2026

Verification status: Metadata observed; artifact bytes were not independently fetched or hashed by this catalog import. The digest below is source-reported.

Source-reported sha256: c2c9302973a93f93bbf18392384b7764ca398dcd61e4d69d286c4f7cbfe3a99e

After downloading that exact artifact, compare its bytes with the source-reported expected digest:

printf '%s %s\n' 'c2c9302973a93f93bbf18392384b7764ca398dcd61e4d69d286c4f7cbfe3a99e' 'libffado-devel-2.4.9-8.fc43.x86_64.rpm' | sha256sum --check --strict -

A match establishes equality with the repository metadata value. It does not establish safety or catalog-side artifact retrieval.

Field source: Fedora 43 Everything x86_64 revision 43-everything-x86_64:eb1d8634a798b5cfcef64b0114711f431f2cd186b55cce902f1883a32c6ff4f2

Completezza del record

The completeness score measures metadata coverage, not software quality, security, compatibility, or suitability.

Summary and description
25/25
Artifact path and source digest
25/25
Dependency metadata
15/15
Package-file index
15/15
Homepage
5/5
License text
5/5
Source package or maintainer
10/10

Recorded total: 100/100

Field source: Fedora 43 Everything aarch64 revision 43-everything-aarch64:6431612747d987257399969298151d19cfe87ed26322be6987e7b00cd0ae66a2, Fedora 43 Everything x86_64 revision 43-everything-x86_64:eb1d8634a798b5cfcef64b0114711f431f2cd186b55cce902f1883a32c6ff4f2. The cross-OS mapping is catalog-derived from the source-reported homepage; it does not establish authorship or publisher identity

Fonti e provenienza

Field-source links above resolve here. Each source entry names the metadata publisher, trust tier, exact snapshot revision, signature result, and observation time; catalog-derived mappings are labeled separately.

  • Authoritative source; repository metadata signature verified, revision 43-everything-aarch64:6431612747d987257399969298151d19cfe87ed26322be6987e7b00cd0ae66a2

    Signature verification covers the configured repository metadata chain. It does not certify that the package is safe or suitable.

    Repository-signature verification record
    Signed-object SHA-256
    6c2a7b7225a6bd12acd5c95dcd0350a0a5929e195692ff68eb31db0ee6b9897b
    Signer fingerprint
    Not recorded
    Keyring revision
    RPM-GPG-KEY-fedora-43-primary
    SHA-256 2b1449a082d3264dda8e18369f04e9ac4163bf3f8cb530b0783dc2ab064a08ec
    Tool and policy
    1
    openfactory-software-catalog-signature-v1
    Verification time
    Sep 1, 2026
    Signed Release → package-index hash linkage

    Path: Not recorded
    Expected SHA-256: Not recorded
    Observed SHA-256: Not recorded
    Result: match verified

  • Authoritative source; repository metadata signature verified, revision 43-everything-x86_64:eb1d8634a798b5cfcef64b0114711f431f2cd186b55cce902f1883a32c6ff4f2

    Signature verification covers the configured repository metadata chain. It does not certify that the package is safe or suitable.

    Repository-signature verification record
    Signed-object SHA-256
    42c0002750de6066124693fff143f4854c1e29474d893f7e6a7616012d41338f
    Signer fingerprint
    Not recorded
    Keyring revision
    RPM-GPG-KEY-fedora-43-primary
    SHA-256 2b1449a082d3264dda8e18369f04e9ac4163bf3f8cb530b0783dc2ab064a08ec
    Tool and policy
    1
    openfactory-software-catalog-signature-v1
    Verification time
    Sep 1, 2026
    Signed Release → package-index hash linkage

    Path: Not recorded
    Expected SHA-256: Not recorded
    Observed SHA-256: Not recorded
    Result: match verified

libffado-devel Package for Fedora 43 | OpenFactory